<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: Entities.php 3540 2005-08-22 09:09:40Z andrew $
*/

/**
 * A file that contains a number of entity classes used in the Maintenance Priority process.
 */

require_once MAX_PATH . '/lib/core/ServiceLocator.php';
require_once MAX_PATH . '/lib/max/Dal/Maintenance.php';

/**
 * An entity class used to represent placements (used to be campaigns).
 *
 * @package    MaxMaintenance
 * @subpackage Priority
 * @author     Andrew Hill <andrew@m3.net>
 * @author     Demain Turner <demian@m3.net>
 * @author     James Floyd <james@m3.net>
 */
class Placement
{
    
    var $id;
    var $oDal;
    var $adverts           = array();
    var $expire;
    var $views             = 0;
    var $clicks            = 0;
    var $conversions       = 0;
    var $target_impression = 0;
    var $target_click      = 0;
    var $target_conversion = 0;
    var $priority          = 0;
    var $sumRequests       = 0;
    var $sumViews          = 0;
    var $sumClicks         = 0;
    var $sumConversions    = 0;
    
    /**
     * The constructor method.
     *
     * @param array $aPlacement An associative array of values to be assigned to 
     *                          the object, array keys reflect database field names.
     */
    function Placement($aPlacement = array())
    {
        $this->oDal              = $this->_getDal();
        $this->id                = (int)$aPlacement['campaignid'];
        $this->expire            =      $aPlacement['expire'];
        $this->views             = (int)$aPlacement['views'];
        $this->clicks            = (int)$aPlacement['clicks'];
        $this->conversions       = (int)$aPlacement['conversions'];
        $this->target_impression = (int)$aPlacement['target_impression'];
        $this->target_click      = (int)$aPlacement['target_click'];
        $this->target_conversion = (int)$aPlacement['target_conversion'];
        $this->priority          = (int)$aPlacement['priority'];
    }
    
    /**
     * A method to get a reference to the MAX_Dal_Maintenance object.
     *
     * @access private
     */
    function &_getDal()
    {
        $oServiceLocator = &ServiceLocator::instance();
        $oDal = $oServiceLocator->get('MAX_Dal_Maintenance');
        if (!$oDal) {
            $oDal = &MAX_Dal_Maintenance::singleton();
            $oServiceLocator->register('MAX_Dal_Maintenance', $oDal);
        }
        return $oDal;
    }
    
    /**
     * A method to set the placement's adverts array to contain Advert
     * object of each ad in the placement, from the data stored in the
     * database.
     */
    function setAdverts() 
    {
        $aAdverts = $this->oDal->getAdsByPlacementId($this->id);
        if (is_array($aAdverts) && (count($aAdverts) > 0)) {
            foreach ($aAdverts as $aAdvert) {
                $this->adverts[] = new Advert($aAdvert);
            }
        }
    }
    
    /**
     * A method to set the basic placement data and summary of delivery statistics
     * to date, for the placement object, from the data stored in the database.
     */
    function setSummaryStatisticsToDate()
    {
        $aStats = $this->oDal->getPlacementStats($this->id, false);
        $this->sumRequests    = (int)$aStats['sum_requests'];
        $this->sumViews       = (int)$aStats['sum_views'];
        $this->sumClicks      = (int)$aStats['sum_clicks'];
        $this->sumConversions = (int)$aStats['sum_conversions'];
    }
    
    /**
     * A method to set the basic placement data and summary of delivery statistics
     * for today only, for the placement object, from the data stored in the database.
     *
     * @param string $today A "CCYY-MM-DD" formatted representation of today's date.
     */
    function setSummaryStatisticsToday($today)
    {
        $aStats = $this->oDal->getPlacementStats($this->id, true, $today);
        $this->sumRequests    = (int)$aStats['sum_requests'];
        $this->sumViews       = (int)$aStats['sum_views'];
        $this->sumClicks      = (int)$aStats['sum_clicks'];
        $this->sumConversions = (int)$aStats['sum_conversions'];
    }
    
}


/**
 * An entity class used to represent advertisements.
 *
 * @package    MaxMaintenance
 * @subpackage Priority
 * @author     Andrew Hill <andrew@m3.net>
 * @author     Demain Turner <demian@m3.net>
 * @author     James Floyd <james@m3.net>
 */
class Advert
{   
    var $oDal;
    var $id;
    var $type;
    var $weight;
    var $active;
    var $requiredImpressions;
    var $filtered;
    var $zones = array();
    var $pastRequiredImpressions;
    var $pastActualImpressions;
    var $pastAdZonePriorityFactor;
    var $pastZoneTrafficFraction;

    /**
     * The constructor method.
     *
     * @param array $aAdvert An associative array of values to be assigned to 
     *                       the object, array keys reflect database field names.
     */
	function Advert($aAdvert = array())
    {
        $this->oDal = $this->_getDal();
        if (count($aAdvert)) {
            $this->id     = $aAdvert['ad_id'];
            $this->type   = $aAdvert['type'];
            $this->weight = $aAdvert['weight'];
            $this->active = $aAdvert['active'];
        }
    }
    
    function &_getDal()
    {
        $oServiceLocator = &ServiceLocator::instance();
        $oDal = $oServiceLocator->get('MAX_Dal_Maintenance');
        if (!$oDal) {
            $oDal = &MAX_Dal_Maintenance::singleton();
            $oServiceLocator->register('MAX_Dal_Maintenance', $oDal);
        }
        return $oDal;
    }
	
	function getConstraints() 
	{
        $wheres[] = array(  $conf['table']['prefix'] . 
                            $conf['table']['acls'].'bannerid = '.$this->id, 'AND');
		return $this->oDal->getAdLimitations(array(), $wheres);
   /**
    * $aConstraints is an array of max 'limitation' rows, each one like:
    * Array
    *    (
    *        [ad_id] => 3
    *        [logical] => and
    *        [type] => weekday
    *        [comparison] => ==
    *        [data] => 0,6
    *        [executionorder] => 0
    *    )
    */
//        if (is_array($aLimitations) && (count($aLimitations) > 0)) {
//            foreach ($aLimitations as $aLimitation) {
//                $aRet[] = MAX_Maintenance_Priority_Constraint::factory($aLimitation);
//            }    
//    		return $aRet;#ConstraintCollection::factory($aConstraints);
//        }
	}
	
	function setRequiredImpressions($value)
	{
	   $this->requiredImpressions = $value;
	}
	
}

/**
 * An entity class used to represent zones.
 *
 * @package    MaxMaintenance
 * @subpackage Priority
 * @author     Andrew Hill <andrew@m3.net>
 * @author     Demain Turner <demian@m3.net>
 * @author     James Floyd <james@m3.net>
 */
class Zone
{
    
    var $id;
    var $availableImpressions = 0;
    var $averageImpressions   = 0;
    var $aAdverts             = array();
    var $aOperationIntId      = array();
    var $pastActualImpressions;
    
   /**
    * The constructor method.
    *
    * @param array $aZone associative array of values to be assigned to 
    *              object, array keys reflect database field names
    */
    function Zone($aZone = array())
    {
        $this->id = (int)$aZone['zoneid'];
    }
    
    /**
     * A method to add Advert objects to the Zone.
     *
     * @param Advert $ad The Advert object to add.
     */
    function addAdvert($ad)
    {
        $this->aAdverts[$ad->id] = $ad;
    }
    
    /**
     * A method to determine if any of the advertisements with impressions allocated
     * to the zone are filtered, or not.
     *
     * @return boolean Returns true if one or more ad associated with the zone is 
     *                 filtered, false otherwise.
     */
    function containsFilteredAds()
    {
        if (is_array($this->aAdverts) && (count($this->aAdverts) > 0)) {
            foreach ($this->aAdverts as $oAdvert) {
                if ($oAdvert->filtered) {
                    return true;
                }
            }
        }
        return false;
    }
    
   /**
    * Method to set the average impressions for a given 
    * operation interval id
    *
    * @param integer $intervalId
    * @param integer $impressions
    * @return void
    */
    function setIntervalIdImpressionAverage($intervalId, $impressions = 0)
    {
        if (isset($intervalId)) {
            $this->aOperationIntId[$intervalId]['averageImpressions'] = $impressions;
        }
    }
    
   /**
    * Method to set the forecast impressions for a given 
    * operation interval id
    *
    * @param integer $intervalId
    * @param integer $impressions
    * @return void
    */
    function setIntervalIdImpressionForecast($intervalId, $impressions = 0)
    {
        if (isset($intervalId)) {
            $this->aOperationIntId[$intervalId]['forecastImpressions'] = $impressions;
        }
    }
    
   /**
    * Method to set the actual impressions value for a given 
    * operation interval id
    *
    * @param integer $intervalId
    * @param integer $impressions
    * @return void
    */
    function setIntervalIdImpressionActual($intervalId, $impressions = 0)
    {
        if (isset($intervalId)) {
            $this->aOperationIntId[$intervalId]['actualImpressions'] = $impressions;
        }
    }
    
}

?>
